'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _style = require('../_utils/dom/style');

var _scroll = require('../_utils/dom/scroll');

var _event = require('../_utils/dom/event');

var _loading = require('../loading');

var _loading2 = _interopRequireDefault(_loading);

require('./index.less');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

// Components
exports['default'] = {
    model: {
        prop: 'loading'
    },

    props: {
        error: Boolean,
        loading: Boolean,
        finished: Boolean,
        errorText: String,
        loadingText: String,
        finishedText: {
            type: String,
            'default': '没有更多了'
        },
        immediateCheck: {
            type: Boolean,
            'default': true
        },
        offset: {
            type: [Number, String],
            'default': 300
        },
        direction: {
            type: String,
            'default': 'down'
        }
    },

    data: function data() {
        return {
            // use sync innerLoading state to avoid repeated loading in some edge cases
            innerLoading: this.loading
        };
    },


    watch: {
        loading: 'check',
        finished: 'check'
    },

    updated: function updated() {
        this.innerLoading = this.loading;
    },
    mounted: function mounted() {
        this.scroller = (0, _scroll.getScroller)(this.$el);
        (0, _event.on)(this.scroller, 'scroll', this.check, true);

        if (this.immediateCheck) {
            this.check();
        }
    },
    beforeDestroy: function beforeDestroy() {
        (0, _event.off)(this.scroller, 'scroll', this.check);
    },


    methods: {
        // @exposed-api
        check: function check() {
            var _this = this;

            this.$nextTick(function () {
                if (_this.innerLoading || _this.finished || _this.error) {
                    return;
                }

                var el = _this.$el,
                    scroller = _this.scroller,
                    offset = _this.offset,
                    direction = _this.direction;

                var scrollerRect = void 0;

                if (scroller.getBoundingClientRect) {
                    scrollerRect = scroller.getBoundingClientRect();
                } else {
                    scrollerRect = {
                        top: 0,
                        bottom: scroller.innerHeight
                    };
                }

                var scrollerHeight = scrollerRect.bottom - scrollerRect.top;

                /* istanbul ignore next */
                if (!scrollerHeight || (0, _style.isHidden)(el)) {
                    return false;
                }

                var isReachEdge = false;
                var placeholderRect = _this.$refs.placeholder.getBoundingClientRect();

                if (direction === 'up') {
                    isReachEdge = scrollerRect.top - placeholderRect.top <= offset;
                } else {
                    isReachEdge = placeholderRect.bottom - scrollerRect.bottom <= offset;
                }

                if (isReachEdge) {
                    _this.innerLoading = true;
                    _this.$emit('input', true);
                    _this.$emit('load');
                }
            });
        },
        clickErrorText: function clickErrorText() {
            this.$emit('update:error', false);
            this.check();
        },
        genLoading: function genLoading() {
            var h = this.$createElement;

            if (this.innerLoading && !this.finished) {
                return h(
                    'div',
                    { 'class': 'loading', key: 'loading' },
                    [this.$slots['loading'] || h(_loading2['default'], {
                        attrs: {
                            spinning: 'spinning',
                            turn: true,
                            tip: this.loadingText
                        }
                    })]
                );
            }
        },
        genFinishedText: function genFinishedText() {
            var h = this.$createElement;

            if (this.finished) {
                var text = this.$slots['finished'] || this.finishedText;

                if (text) {
                    return h(
                        'div',
                        { 'class': 'sn-list-finished-text' },
                        [text]
                    );
                }
            }
        },
        genErrorText: function genErrorText() {
            var h = this.$createElement;

            if (this.error) {
                var text = this.$slots['error'] || this.errorText;

                if (text) {
                    return h(
                        'div',
                        {
                            on: {
                                'click': this.clickErrorText
                            },
                            'class': 'sn-list-error-text' },
                        [text]
                    );
                }
            }
        }
    },

    render: function render() {
        var h = arguments[0];
        var $slots = this.$slots;

        var Placeholder = h('div', { ref: 'placeholder', 'class': 'sn-list-placeholder' });

        return h(
            'div',
            { 'class': 'sn-list', attrs: { role: 'feed', 'aria-busy': this.innerLoading }
            },
            [this.direction === 'down' ? $slots['default'] : Placeholder, this.genLoading(), this.genFinishedText(), this.genErrorText(), this.direction === 'up' ? $slots['default'] : Placeholder]
        );
    }
}; // Utils

module.exports = exports.default;