'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

exports.PromiseJSBridgeReady = PromiseJSBridgeReady;
exports.callHandler = callHandler;
exports.registerHandler = registerHandler;
exports.CheckNetWorkFunction = CheckNetWorkFunction;
exports.GetUserInfoFunction = GetUserInfoFunction;
exports.EncryptionFunction = EncryptionFunction;
exports.DecryptionFunction = DecryptionFunction;
exports.getUrlParamsFromAli = getUrlParamsFromAli;
exports.openAppRoute = openAppRoute;
exports.bridgeOpenPage = bridgeOpenPage;
exports.addAppViewListener = addAppViewListener;
exports.RegisterMenuFunction = RegisterMenuFunction;
exports.mPaasPopTo = mPaasPopTo;
exports.goBackFunction_new = goBackFunction_new;
exports.goBackFunction = goBackFunction;
exports.getBankType = getBankType;
exports.GetLocalDataFunction = GetLocalDataFunction;
exports.QrcodeScan = QrcodeScan;

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

require("./SnJSBridge.js");

//当前页面用到的常量cccc
var _ALI_JS_BRIDGE = 'AlipayJSBridge';
var _Sn_JS_BRIDGE = 'SnJSBridge';
var AlipayJSBridge = void 0,
    SnJSBridge = void 0;
//通用JSBridgeReady事件 Promise 版，
//目前支持 AlipayJSBridge，SnJSBridge（TChat）
// 2019.05.21 zw
function PromiseJSBridgeReady(callback) {
    // 如果 jsbridge 已经注入则直接调用
    if (window[_ALI_JS_BRIDGE] || window[_Sn_JS_BRIDGE]) {
        AlipayJSBridge = window.AlipayJSBridge;
        SnJSBridge = window.SnJSBridge;
        callback && callback();
    } else {
        // 如果没有注入则监听注入的事件
        document.addEventListener('AlipayJSBridgeReady', function () {
            AlipayJSBridge = window.AlipayJSBridge;
            callback && callback();
        }, false);
        document.addEventListener('SnJSBridgeReady', function () {
            SnJSBridge = window.SnJSBridge;
            callback && callback();
        }, false);
    }
    //监听注入的事件
    //document.addEventListener('AlipayJSBridgeReady', callback, false);  //ali
    //document.addEventListener(`${_TCHAT_JS_BRIDGE_NAME}Ready`, () => callback(_TCHAT_JS_BRIDGE_NAME), false); //other
}

// 发送数据
var uniqueId = 1;
var u = navigator.userAgent,
    app = navigator.appVersion;
var isAndroid = u.indexOf('Android') > -1 || u.indexOf('Linux') > -1; //g


function callHandler(method, data) {
    var type = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "mPaaSAdapterEvent";

    return new Promise(function (resolve, reject) {
        PromiseJSBridgeReady(function () {
            if (window[_Sn_JS_BRIDGE]) {
                SnJSBridge.callHandler(method, data, function (responseData) {
                    try {
                        if (responseData) {
                            resolve(JSON.parse(responseData));
                        }
                    } catch (e) {
                        resolve(responseData);
                    }
                });
            } else if (window[_ALI_JS_BRIDGE]) {
                var sendData = {
                    handlerName: method,
                    data: data
                };
                console.log('sendData = ' + JSON.stringify(sendData));
                if (!!isAndroid) {
                    sendData.callbackId = 'cb_' + uniqueId++ + '_' + new Date().getTime();
                }
                AlipayJSBridge.call(type, sendData, function (result) {
                    console.log('3调用的方法名是：' + method + '-----------------3返回的数据是：' + JSON.stringify(result));
                    try {
                        if (result.mPaaSAdapterEvent && result.mPaaSAdapterEvent.responseData) {
                            resolve(JSON.parse(result.mPaaSAdapterEvent.responseData));
                        } else {
                            resolve(result);
                        }
                    } catch (e) {
                        resolve(result.mPaaSAdapterEvent && result.mPaaSAdapterEvent.responseData);
                    }
                });
            } else {
                reject("no bridge");
            }
        });
    });
}

var mPassAddEventListener = function mPassAddEventListener() {};

// 注册阿里的jsbridge  js注册方法等待App调用
function registerHandler(method, callback) {
    PromiseJSBridgeReady(function () {
        if (SnJSBridge) {
            return SnJSBridge.registerHandler(method, function (data) {
                callback(data);
            });
        } else if (AlipayJSBridge) {
            if (method === 'notifyAppBack') {
                method = 'back';
            }
            if (method === 'refreshPage') {
                method = 'resume';
            }
            mPassAddEventListener = function mPassAddEventListener(event) {
                console.log('4主动注册时间：' + method + '-----------------4主动返回的数据是：' + JSON.stringify(event));
                event.preventDefault && event.preventDefault();
                callback && callback(event.data);
            };
            document.addEventListener(method, mPassAddEventListener);
        }
    });
}

/**
 * 获取网络状态
 * boolean contectState;//  false 未连接，true已连接
   int netType;// 1 WIFI，2是数据 0，默认值无意义
 */
function CheckNetWorkFunction() {
    return callHandler('CheckNetWorkFunction', '');
}

/**
 * js调用 Native 获取用户信息
 * @export
 */
function GetUserInfoFunction() {
    var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    return callHandler('GetUserInfoFunction', data);
}

/**
 * js调用 Native 加解密
 * @export
 */
function EncryptionFunction(data) {
    return callHandler('EncryptionFunction', data);
}

function DecryptionFunction(data) {
    return callHandler('DecryptionFunction', data);
}

//获取url中页面重定向次数数组
function getRedirectionCnt(url) {
    var redirectionCnt = void 0;
    var redirectionCntRegRes = url.match(/[?|&]redirectionCnt=([^&#]*)(#|&|$)/);
    if (redirectionCntRegRes) {
        redirectionCnt = JSON.parse(decodeURI(redirectionCntRegRes[1]));
    } else {
        redirectionCnt = [];
    }
    return redirectionCnt;
}

//兼容安卓升级之后的参数获取

function changehash(urlParams) {
    var url = '';
    PromiseJSBridgeReady(function () {
        if (window.AlipayJSBridge && window.AlipayJSBridge.startupParams && window.AlipayJSBridge.startupParams.passData) {
            //如果是ali mPaaS环境，需要从启动参数内获取完整url
            url = JSON.parse(window.AlipayJSBridge.startupParams.passData).homeAddr || url;
            var route = url.split('.html')[1]; //运营平台配的当前应用启动页，即入口页面应用的启动页
            //1. 获取当前页参数
            var params = window.location.href.split('?')[1] || '';
            var TGC = urlParams && urlParams.TGC ? urlParams.TGC : '';
            if (params && params.indexOf('TGC=') > -1) {
                //取出TGC
                TGC = params.split('TGC=')[1] || TGC;
                console.log('TGC=', TGC);
            }
            if (params && 1 < Object.keys(urlParams).length) {//参数中只有TGC的情况需要排除

            } else {
                // TGC = 2>Object.keys(urlParams).length&&!!urlParams.TGC?urlParams.TGC:TGC; //取出APP带过来的TGC
                var openUrl = '' + window.location.href + route; //TGC这里可能有问题，需要多场景测试处理
                //window.location.href = openUrl
                window.location.replace(openUrl);
            }
            console.log('window.location.href:', window.location.href);
        }
    });
}

function getUrlParamsFromAli() {
    var type = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
    var urlParams = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    var url = window.location.href;
    var regexP = /[^#&\?]+=[^#&\?]*/ig;
    var ms = url.match(regexP);
    if (!ms && type && window.AlipayJSBridge && window.AlipayJSBridge.startupParams && window.AlipayJSBridge.startupParams.passData) {
        //如果是ali mPaaS环境，需要从启动参数内获取完整url, 2019-09-29 zw
        url = JSON.parse(window.AlipayJSBridge.startupParams.passData).homeAddr || url;
        ms = url.match(regexP);
    } else if (!ms && !window.AlipayJSBridge) {
        _vue2['default'].nextTick(function () {
            changehash(urlParams);
        });
    }

    if (ms) {
        for (var i = 0; i < ms.length; i++) {
            var arr = ms[i].split('=');
            try {
                arr[1] = decodeURI(decodeURIComponent(arr[1]));
            } catch (e) {
                arr[1] = decodeURIComponent(arr[1]);
            }
            urlParams[arr[0]] = arr[1];
        }
    }
    if (urlParams && urlParams.TGC) {
        //TGC特殊处理
        urlParams.TGC = urlParams.TGC;
    }
    return urlParams;
}

// 兼容mPaaS离线包，打开单页小应用对应的路由地址
// 从其他应用跳转的应用需要在入口页面做处理，这里不处理
function openAppRoute() {
    var url = '';
    if (window.AlipayJSBridge && window.AlipayJSBridge.startupParams && window.AlipayJSBridge.startupParams.passData) {
        //如果是ali mPaaS环境，需要从启动参数内获取完整url
        url = JSON.parse(window.AlipayJSBridge.startupParams.passData).homeAddr || url;
        var route = url.split('.html')[1]; //运营平台配的当前应用启动页，即入口页面应用的启动页
        var appHref = url.split('.html')[0].split('/pages/')[1];
        //1. 获取当前页参数
        var params = window.location.href.split('?')[1] || '';
        //2. 获取页面hash
        var locationHash = window.location.hash.split('?')[0];
        var routeSplit = route.split('?')[1];
        if (routeSplit && routeSplit.indexOf('ukey=') > -1) {
            //去除ukey
            //routeSplit = routeSplit.split('#/')[1] || route.split('#/')[1].split('?')[0] || route.split('#/')[1] || route
            routeSplit = routeSplit.split('#/')[1] || route.split('#/')[1] || route;
        }
        if (route.split('?')[1] && 0 === route.split('?')[1].indexOf('TGC=')) {
            route = route.split('?')[0];
        }
        if (routeSplit && 0 === routeSplit.indexOf('TGC=')) {
            routeSplit = route;
        }
        if (params.indexOf('#/') > -1) {
            params = params.split('#/')[0] || '';
        }
        if (!route) {
            //没有route 场景 , 不用跳转
        } else if (route.split('?')[0] === locationHash && locationHash !== '#/') {
            //route 相同，do sth , 不用跳转  //非离线包的打开应用场景
        } else if (routeSplit === locationHash.split('#/')[1]) {
            //route 相同
        } else {
            // 3. 拼接参数，打开对应路由页面
            // window.location.hash = route.split('?')[1] ? `${routeSplit}?&${params}` : `${routeSplit}?${params}`;
            var reRoute = routeSplit ? routeSplit : route;
            var hash = route.split('?')[1] ? reRoute + '?&' + params : reRoute + '?' + params;
            //let hash = route.split('?')[1] ? `${routeSplit}?&${params}` : `${routeSplit}?${params}`;
            //window.location.hash = route.split('?')[1] ? `${route}?&${params}` : `${route}?${params}`
            _vue2['default'].nextTick(function () {
                console.log('hash:', hash);
                console.log('appHref:', appHref);
                // window.location.hash = hash.indexOf('#/') > -1 ? hash : `#/${hash}`
                var realHash = hash.indexOf('#/') > -1 ? hash : '#/' + hash;
                window.location.href = appHref + '.html' + realHash; //兼容小应用匹配多个离线包 2019-12-11 zw
            });
        }
        //console.log('window.location.hash:', window.location.hash)
    }
}

function bridgeOpenPage(url) {
    PromiseJSBridgeReady(function () {
        //url中参数sswbv_multipage=false，当前页面重定向，其它新开页面
        var sswbv_multipage = true;
        var sswbvMultiPageRegRes = url.match(/[?|&]sswbv_multipage=([^&]*)(&|$)/);
        if (sswbvMultiPageRegRes) {
            sswbv_multipage = sswbvMultiPageRegRes[1];
        }
        // let redirectionCnt = getRedirectionCnt(window.location.href)
        if (sswbv_multipage === 'false') {
            window.open(url);
        } else if (SnJSBridge) {
            //T信平台使用window.open打开新页面
            window.open(url);
        } else if (AlipayJSBridge) {
            // if (sswbv_multipage == 'false') {
            //     redirectionCnt[0] = (redirectionCnt[0] || 0) + 1;
            // } else { 
            //     redirectionCnt.unshift(0);
            // }
            // if(url.indexOf('?') != -1) {
            //     url += "&redirectionCnt=" + JSON.stringify(redirectionCnt);
            // } else {
            //     url += "?redirectionCnt=" + JSON.stringify(redirectionCnt);
            // }
            // window.location.href = encodeURI(decodeURI(url));
            // mPaas平台新开页面
            AlipayJSBridge.call('pushWindow', {
                url: encodeURI(url),
                param: {
                    readTitle: true,
                    showOptionMenu: false,
                    titleBarColor: 4688622 //兆日蓝，加载页面之前就设置标题背景颜色
                }
            });
        } else {
            console.log("bridgeOpenPage：error");
        }
    });
}

/**
 * 增加app页面监听事件
 * @param {Object} appViewId        事件Id
 * @param {Object} appViewAction    app事件
 * @param {Object} appViewOperator  app显示
 * @param {Object} appViewName      app显示名称
 * @param {Object} func             回调函数
 */
function addAppViewListener(appViewId, appViewAction, appViewOperator, appViewName, func) {
    callHandler('addAppViewListener', {
        appViewId: appViewId,
        appViewAction: appViewAction,
        appViewOperator: appViewOperator,
        appViewName: appViewName
    });
    /**
     * 注册点击app按钮回调
     */
    registerHandler('appViewCallBack', function (data) {
        if (func) {
            func();
        }
    }.bind(this));
}

/**
 * 监听app菜单监听事件
 * @param {Object} menuList
 *  {
      List<MenuItem>  menuList;
    }
 
    MenuItem {
     String name;  //  如果是菜单，用name显示菜单文字
     String iconNormalBase64;  // 如果是图标按钮，用来显示 正常图标（JS交互时，用base64转码，如果图片超过5k，提出来让UI重新切图）
     String iconPressedBase64; // 如果是图标按钮，用来显示 按下效果 图标（JS交互时，用base64转码，如果图片超过5k，提出来让UI重新切图）
     String menuId;  //必填   菜单ID （不区分是 图标按钮 或是 菜单项），列表中的menuId必须相互唯一
     Int type;  // 必填 类型 1 ActionBar上的图标按钮，2 下拉菜单项 3 title显示（一般情况下，只有一个图标按钮，可以有多个下拉菜单项）
    }
   注意
    name 和 iconNormalBase64 至少需要填写一个；
    name 和iconNormalBase64 都有值时ActionBar上的按钮优先显示name，下拉菜单项会左边显示图标，右边显示name；
        当有多个type 为1的item时，app会取第一个值；
        下拉菜单项显示顺序默认按menuList的顺序排序；
_this.initTitle = ['考勤统计',{name:'设置',menuId:'but_1_1',type: 1,func:function(){openPage('setting.html')}}];
_this.initTitle = ['考勤统计',{name:'设置',func:function(){openPage('setting.html')}}];
 */
function RegisterMenuFunction(menuList) {
    var _this2 = this;

    PromiseJSBridgeReady(function () {
        // if (window[_ALI_JS_BRIDGE]) {
        //     setMPaasTitle(menuList[0].name);
        //     //三种菜单有优先级icontype >title>icon  混合类型不支持，比如一个title 和一个自定义iCon 不可以，icon设置必须带上data:image/png;base64,
        //     setMPaasRightMenu(menuList);
        // } else {
        callHandler('RegisterMenuFunction', menuList);
        registerHandler('clickMenuCallBack', function (data) {
            var dataJson = data;
            if ((typeof data === 'undefined' ? 'undefined' : (0, _typeof3['default'])(data)) !== 'object') {
                dataJson = JSON.parse(data);
            }
            // 找出menuList中的与注册事件对应的函数并且执行
            if (menuList) {
                //取对应的func执行 
                for (var i = 0; i < menuList.length; i++) {
                    if (dataJson.menuId === menuList[i].menuId && menuList[i].func) {
                        menuList[i].func();
                        break;
                    }
                }
            }
        }.bind(_this2));
        // }
    });
}
// export function setMPaasTitleColor(color) {
//     PromiseJSBridgeReady(() => {
//         AlipayJSBridge.call("setTitleColor", {
//             color: parseInt(color, 16),
//             reset: false
//         });
//     });
// }
// function setMPaasTitle(titleName) {
//     PromiseJSBridgeReady(() => {
//         AlipayJSBridge.call('setTitle', {
//             title: titleName
//         });//第三个参数是设置成功之后的回调，无用
//     });
// }
// function setMPaasRightMenu(menuList) {
//     PromiseJSBridgeReady(() => {
//         if (menuList.length <= 1)
//             return;
//         //表示右上角按钮设置了，因此调用设置menu
//         AlipayJSBridge.call('setOptionMenu', {
//             menus: formatMenu(menuList),
//             override: true
//         });

//         // 必须强制调用一次以刷新界面
//         AlipayJSBridge.call('showOptionMenu');
//     });
//     document.addEventListener('optionMenu', function (e) {
//         console.log("option menu clicked " + JSON.stringify(e));
//         let index = e.data.index;
//         if (!!menuList[index].func) {
//             menuList[index].func();
//         }
//     }, false);
// }
/**
 * 
 * @param {*} menuList
 * let initTitle = ['考勤统计',{iconNormalBase64:'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAADwAAAA8AQMAAAAAMksxAAAABlBMVEUAAADaYkwN2A23AAAAAXRSTlMAQObYZgAAABpJREFUKM9jAAJ+EDESGf8h4AMexmBx6kAwANuWIu3fRgxoAAAAAElFTkSuQmCC',type: 1,func:function(){alert('设置按钮点击1')}}];
 * let initTitle = ['考勤统计',{name:'设置',color:'#00ffff', func:function(){alert('设置按钮点击')}}];
 * let initTitle = ['考勤统计',{icontype:'scan'}];
 * let initTitle = ['考勤统计http',{iconhttp:'https://yqtblackbox.sinosun.com:18094/static/22.png',type: 1,func:function(){alert('红色按钮点击')}}];
 * iconhttp
 * icontype 选择范围：
 * 具体类型包含: user（账户）、filter（筛选器）、search（查找）、add（添加）、
 * settings（设置）、scan（扫一扫）、info（信息）、help（帮助）、locate（定位）、more（更多）、mail（邮箱 10.0.8 及以上） 
*/
// function formatMenu(menuList) {
//     let menuBuf = [];
//     menuList.splice(0, 1);//删除title标题栏 
//     menuList.forEach(item => {
//         //遍历获取
//         if (!!item.name && item.name.length > 0 && item.name !== '刷新' && item.name !== 'true' && item.name !== 'false') {
//             //设置右边按钮的名称
//             let tempObj = {
//                 redDot: '-1',
//                 title: item.name
//             };
//             if (!!item.color && item.color.length > 0) {
//                 tempObj.color = item.color;
//             }
//             menuBuf.push(tempObj);
//         } else if (!!item.iconNormalBase64 && item.iconNormalBase64.length > 0) {
//             //兼容我们传过来的base64
//             menuBuf.push({
//                 redDot: '-1',
//                 icon: item.iconNormalBase64
//             });
//         } else if (!!item.iconhttp && item.iconhttp.length > 0) {
//             menuBuf.push({
//                 redDot: '-1',
//                 icon: item.iconhttp
//             });
//         } else if (!!item.icontype && item.icontype.length > 0) {
//             //使用mpaas的menu
//             menuBuf.push({
//                 redDot: '-1',
//                 icontype: item.icontype
//             });
//         } else {
//             console.error('initTitleMenu error ');
//         }
//     });
//     return menuBuf;
// }

function mPaasPopTo(backSteps, loadData) {
    // let redirectionCntArr = getRedirectionCnt(window.location.href);
    // let redirectionCnt = redirectionCntArr.slice(0, backSteps).reduce((sum, cur) => (sum + cur), 0);
    // let indexSteps = Number(backSteps) + redirectionCnt;
    // if (window.history.length <= indexSteps) {
    //     AlipayJSBridge.call('popWindow');
    // } else { 
    //     window.history.go("-" + indexSteps);
    // }
    // let indexSteps = "-" + Number(backSteps);
    // AlipayJSBridge.call('popTo', {
    //     index: Number(indexSteps)
    // }, function (e) {
    //     console.log("AliReady goBackFunction_new failed: ", e);
    //     if (!!isAndroid) {
    //         AliReady(function () {
    //             AlipayJSBridge.call('exitApp', "exitSelf");
    //         })
    //     } else {
    //         AliReady(function () {
    //             AlipayJSBridge.call('exitIOSApp', "exitSelf");
    //         })
    //     }
    // });


    backSteps -= 1;
    if (backSteps < 0) {
        return;
    }
    PromiseJSBridgeReady(function () {
        AlipayJSBridge.call('popWindow', {
            data: {
                backSteps: backSteps,
                loadData: loadData
            }
        });
    });
}

/**
 * 回退页面
 * @param {Object} url  //目标页面url
 */
function goBackFunction_new(url, backSteps, loadData) {
    PromiseJSBridgeReady(function () {
        if (window.AlipayJSBridge) {
            if (!!backSteps) {
                mPaasPopTo(backSteps, loadData);
            } else {
                goBackFunction(url);
            }
        } else {
            var data = {
                loadData: '',
                url: url
            };
            if (backSteps) {
                data.backSteps = backSteps;
            }
            if (loadData) {
                data.loadData = loadData;
            }
            callHandler('goBackFunction', JSON.stringify(data));
        }
    });
}

/**
 * 回退页面
 * @param {Object} url  //目标页面url
 */
function goBackFunction(url) {
    PromiseJSBridgeReady(function () {
        if (!AlipayJSBridge) {
            callHandler('goBackFunction', JSON.stringify({
                loadData: '',
                url: url
            }));
            return;
        };
        if (!!url) {
            AlipayJSBridge.call('popTo', {
                urlPattern: url
            });
        } else {
            mPaasPopTo(1);
        }
    });
}

/* 获取App的BankType 
 * 2：厦门银行
 * 3：华夏银行
 * */
function getBankType(vm) {
    var _this = vm;
    callHandler('GetAppConfigFunction', {
        key: 'bankId'
    }).then(function (data) {
        // console.log('before:' + _this.appBankType);
        if (3 === Number(data.value)) {
            //华夏银行
            _this.appBankType = 2;
        } else {
            //厦门银行
            _this.appBankType = 1;
        }
        // console.log('after:' + _this.appBankType);
    });
}

/**
 * 获取基本配置信息
 */
function GetLocalDataFunction(data) {
    //临时数据
    var result = {
        "ret": 0,
        "IMEI": 1111111111,
        "terType": 0
    };
    return result;
}

/**
 * 扫描二维码
 */
function QrcodeScan() {
    var Json = {
        action: 'action_common_qrcode_scan',
        dataList: [{
            key: 'userid',
            value: 'abc1',
            type: "string"
        }, {
            key: 'userid',
            value: 'abc2',
            type: "string"
        }, {
            key: 'userid',
            value: 'abc3',
            type: "string"
        }],
        responseKeyList: [{
            key: 'qrcode',
            value: '',
            type: 'string'
        }]
    };
    return callHandler('OpenActionFunction', Json).then(function (result) {
        var res = JSON.stringify(result);
        var resultJson = JSON.parse(res.substring(1, res.length - 1));
        var resultValue = resultJson.value;
        return resultValue;
    });
}

//  监听页面回复运行
mPassAddEventListener = function mPassAddEventListener(event) {
    console.log('5页面是否关闭，注册事件：resume -----------------返回的数据是：' + JSON.stringify(event));
    var backSteps = event.data && event.data.backSteps || 0;
    var loadData = event.data && event.data.loadData || '';
    if (backSteps > 0) {
        mPaasPopTo(backSteps, loadData);
    }
};
document.addEventListener('resume', mPassAddEventListener);