'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

require('./index.less');

var _input = require('../mixins/input');

var _input2 = _interopRequireDefault(_input);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var Textarea = {
    mixins: [_input2['default']],

    props: {
        rows: {
            type: [String, Number],
            'default': 1
        },
        autosize: {
            type: Boolean,
            'default': true
        },
        maxlength: {
            type: Number,
            'default': 200
        }
    },

    computed: {
        style: function style() {
            var style = {
                height: this.height || 'auto'
            };
            if (this.maxHeight) {
                style.maxHeight = this.maxHeight;
            }
            return style;
        }
    },
    methods: {
        setValue: function setValue(value) {
            this.$refs.textarea.value = value;
        },
        onInput: function onInput(event) {
            this.$refs.textarea.style.height = "auto";
            if (this.autosize) {
                this.$refs.textarea.style.height = this.$refs.textarea.scrollHeight + "px";
            }
            this.$emit("input", event.target.value);
        },
        onFocus: function onFocus(e) {
            this.$emit("onFocus", e);
        },
        onBlur: function onBlur(e) {
            this.$emit("onBlur", e);
        },
        onChange: function onChange(e) {
            this.$emit("onChange", event.target.value);
        }
    },
    render: function render() {
        var h = arguments[0];
        var value = this.value,
            rows = this.rows,
            placeholder = this.placeholder,
            maxlength = this.maxlength,
            editable = this.editable,
            disabled = this.disabled;


        return h('textarea', {
            ref: 'textarea',
            'class': 'sn-textarea',
            attrs: { rows: rows,

                placeholder: placeholder,
                maxlength: maxlength,
                readonly: !editable,

                disabled: disabled
            },
            style: this.style, domProps: {
                'value': value
            },
            on: {
                'input': this.onInput,
                'focus': this.onFocus,
                'blur': this.onBlur,
                'change': this.onChange
            }
        });
    }
};

exports['default'] = Textarea;
module.exports = exports.default;