'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _icon = require('../icon');

var _icon2 = _interopRequireDefault(_icon);

require('./upload-list.less');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var iconMap = { 'Excel': 'file-excel', 'Word': 'file-word', 'MUSIC': 'file-music', 'PDF': 'file-pdf', 'PPT': 'file-ppt', 'TXT': 'file-text', 'VIDEO': 'file-video', 'COMPRESS': 'file-compress' };
var fjType = ['IMG', 'Word', 'Excel', 'PPT', 'PDF', 'TXT', 'COMPRESS', 'MUSIC', 'VIDEO'];
var mimeTypeList = [['image', 'webp', 'svg', 'ico', 'bmp', 'jpg', 'jpeg', 'png', 'gif'], //IMG
['doc', 'docx', 'dot', 'dotx', 'docm'], //Word
['xlsx', 'xls', 'xlsm'], //Excel
['pptx', 'pptm', 'ppt'], //PPT
['pdf'], //PDF
['txt'], //TXT
['rar', 'zip', 'gz', '7z'], //COMPRESS
['mp3', 'rm', 'amr', 'wav', 'ogg', 'midi', '3gpp'], //MUSIC
['avi', 'flv', 'wmv', 'mp4', 'rmvb', 'mov']]; //VIDEO


var previewFile = function previewFile(file, callback) {
    if (file.type) {
        var type = file.type.split("/")[0];
        if (!getFileType(file) === "IMG") {
            return callback('');
        }
    }
    var reader = new window.FileReader();
    reader.onloadend = function () {
        callback(reader.result);
    };
    reader.readAsDataURL(file);
};

var getFileType = function getFileType(file) {
    var name = file.name || file.fileName;
    var arr = name.split(".");
    var mimeType = arr[arr.length - 1].toLowerCase();
    var extension = null;
    for (var i = 0; i < mimeTypeList.length; i++) {
        // 循环查找
        if (mimeTypeList[i].contains(mimeType)) {
            extension = fjType[i];
            break;
        } else {
            //如果不在支持的附件列表则返回后缀
            if (i === mimeTypeList.length - 1) {
                extension = mimeType;
                break;
            }
        }
    }
    return extension;
};

var isImage = function isImage(file, type) {
    if (!type) {
        type = getFileType(file);
    }
    if (type === "IMG") {
        return true;
    } else {
        return false;
    }
};

exports['default'] = {
    name: 'UploadList',
    components: {
        Icon: _icon2['default']
    },
    props: {
        items: {
            type: Array,
            'default': function _default() {
                return [];
            }
        },
        listType: {
            type: String
        },
        showRemoveIcon: {
            type: Boolean,
            'default': true
        },
        showPreviewIcon: {
            type: Boolean,
            'default': true
        }
    },
    data: function data() {
        return {
            prefixCls: 'sn-upload'
        };
    },
    updated: function updated() {
        var _this = this;

        this.$nextTick(function () {
            _this.items.map(function (file, index) {
                if (file.thumbUrl !== undefined) {
                    return;
                }
                _this.$set(file, "thumbUrl", '');
                previewFile(file.originFileObj, function (previewDataUrl) {
                    file.thumbUrl = previewDataUrl;
                });
            });
        });
    },

    methods: {
        /**
         * @description: 上传失败点击重传
         * @param {type} 
         */
        handleError: function handleError(e, file, index) {
            var handleError = this.$listeners.handleError;

            if (!handleError) {
                return;
            }
            e.preventDefault();
            return this.$emit('handleError', file, index);
        },
        handleRemove: function handleRemove(file, index) {
            this.$emit("remove", file, index);
        },
        handlePreview: function handlePreview(file, e) {
            var preview = this.$listeners.preview;

            if (!preview) {
                return;
            }
            e.preventDefault();
            return this.$emit('preview', file);
        },
        handleDownload: function handleDownload(file, e) {
            var download = this.$listeners.download;

            if (!download) {
                return;
            }
            e.preventDefault();
            return this.$emit('download', file);
        }
    },
    render: function render() {
        var _this2 = this;

        var h = arguments[0];
        var _$props = this.$props,
            items = _$props.items,
            listType = _$props.listType;
        var prefixCls = this.$data.prefixCls;

        var listClassNames = [prefixCls + '-list', prefixCls + '-list-' + listType];

        var list = items.map(function (file, index) {
            var itemClassNames = [prefixCls + '-list-item', prefixCls + '-list-item-' + (file.status || 'uploaded')];
            var icon = void 0;
            if (file.percent >= 100) {
                if (file.status !== 'uploaded') {
                    file.percent = Math.ceil(90 + Math.random() * 9);
                } else {
                    file.percent = 100;
                }
            }
            if (isImage(file)) {
                var fileUrl = file.dlUrl || file.previewUrl || file.url || file.thumbUrl;
                icon = fileUrl ? h(
                    'a',
                    {
                        attrs: { href: fileUrl },
                        on: {
                            'click': function click(e) {
                                return _this2.handleDownload(file, e);
                            }
                        }
                    },
                    [file.status === 'uploaded' ? h('img', {
                        attrs: { src: fileUrl }
                    }) : file.status === 'upload-error' ? h(_icon2['default'], {
                        attrs: { type: 'file-failed' },
                        on: {
                            'click': function click(e) {
                                return _this2.handleError(e, file, index);
                            }
                        }
                    }) : h(
                        'span',
                        { 'class': 'sn-upload-list-item-progress' },
                        [file.percent]
                    )]
                ) : file.status === 'uploaded' ? h(_icon2['default'], {
                    attrs: { type: 'picture' }
                }) : file.status === 'upload-error' ? h(_icon2['default'], {
                    attrs: { type: 'file-failed' },
                    on: {
                        'click': function click(e) {
                            return _this2.handleError(e, file, index);
                        }
                    }
                }) : h(
                    'span',
                    { 'class': 'upload-loading' },
                    [file.percent]
                );
            } else {
                var type = getFileType(file);
                var iconType = iconMap[type] || 'picture';
                icon = file.status === 'uploaded' ? fjType.indexOf(type) > -1 ? h(_icon2['default'], {
                    attrs: { type: iconType },
                    on: {
                        'click': function click(e) {
                            return _this2.handleDownload(file, e);
                        }
                    }
                }) : h(_icon2['default'], {
                    attrs: { type: 'picture' }
                }) : file.status === 'upload-error' ? h(_icon2['default'], {
                    attrs: { type: 'file-failed' },
                    on: {
                        'click': function click(e) {
                            return _this2.handleError(e, file, index);
                        }
                    }
                }) : h(
                    'span',
                    { 'class': 'upload-loading' },
                    [file.percent]
                );
            }
            var removeIcon = _this2.showRemoveIcon ? h(_icon2['default'], {
                attrs: { type: 'minus-circle-fill' },
                'class': 'sn-upload-list-item-delete-icon', on: {
                    'click': function click(e) {
                        return _this2.handleRemove(file, index);
                    }
                }
            }) : null;

            return h(
                'div',
                { key: file.uid || file.fileId, 'class': itemClassNames },
                [removeIcon, h(
                    'div',
                    { 'class': 'sn-upload-list-item-con' },
                    [icon, h(
                        'div',
                        { 'class': 'sn-upload-list-item-info' },
                        [file.name || file.fileName]
                    ), h(
                        'div',
                        { 'class': 'preview-con', on: {
                                'click': function click(e) {
                                    return _this2.handlePreview(file, e);
                                }
                            }
                        },
                        ['\u9884\u89C8']
                    )]
                )]
            );
        });
        return items.length ? h(
            'transition-group',
            {
                attrs: { tag: 'div' },
                'class': listClassNames },
            [list]
        ) : null;
    }
};
module.exports = exports.default;